"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var getTmpDir_1 = require("./test/getTmpDir");
var EnvironmentMigrator_1 = require("./EnvironmentMigrator");
var fs = require("fs-extra");
var path = require("path");
var interface_1 = require("./Output/interface");
/**
 * Tests overview
  test('.graphcool with json, non-existent backup file', () => {
  test('.graphcool with json, existing backup file', () => {
  test('.graphcool with yaml, non-existent backup file', () => {
  test('.graphcool with yaml, existing backup file', () => {
  test('.graphcool folder, non-existent backup file, non-existent .graphcoolrc', () => {
  test('.graphcool folder, non-existent backup file, existing .graphcoolrc', () => {
  test('.graphcool folder, non-existent backup file, existing .graphcoolrc', () => {
  test('.graphcoolrc folder, non-existent backup file', () => {
  test('.graphcoolrc folder, existing backup folder (or file)', () => {
  test('.graphcoolrc file with valid yaml, non-existent backup file', () => {
  test('.graphcoolrc file with valid yaml, existing backup folder (or file)', () => {
  test('.graphcoolrc file with invalid yaml, non-existent backup file', () => {
  test('.graphcoolrc file with invalid yaml, existing backup folder (or file)', () => {
 */
describe('EnvironmentMigrator', function () {
    test('.graphcool with json, non-existent backup file', function () {
        var home = getTmpDir_1.getTmpDir();
        fs.outputFileSync(path.join(home, '.graphcool'), '{"example": "Json"}');
        var out = new interface_1.TestOutput();
        var migrator = new EnvironmentMigrator_1.EnvironmentMigrator(home, out);
        migrator.migrate();
        expect(out.output).toMatchSnapshot();
        expect(fs.readdirSync(home)).toMatchSnapshot();
        fs.removeSync(home);
    });
    test('.graphcool with json, existing backup file', function () {
        var home = getTmpDir_1.getTmpDir();
        fs.writeFileSync(path.join(home, '.graphcool'), '{"example": "Json"}');
        fs.writeFileSync(path.join(home, '.graphcool.backup'), '');
        var out = new interface_1.TestOutput();
        var migrator = new EnvironmentMigrator_1.EnvironmentMigrator(home, out);
        migrator.migrate();
        expect(out.output).toMatchSnapshot();
        expect(fs.readdirSync(home)).toMatchSnapshot();
        fs.removeSync(home);
    });
    test('.graphcool with yaml, non-existent backup file', function () {
        var home = getTmpDir_1.getTmpDir();
        fs.outputFileSync(path.join(home, '.graphcool'), "clusters:\n  local:\n    host: 'http://localhost:60000'\n  remote:\n    host: 'https://remote.graph.cool'\n    clusterSecret: 'here-is-a-token'");
        var out = new interface_1.TestOutput();
        var migrator = new EnvironmentMigrator_1.EnvironmentMigrator(home, out);
        migrator.migrate();
        expect(out.output).toMatchSnapshot();
        expect(fs.readdirSync(home)).toMatchSnapshot();
        expect(fs.readFileSync(path.join(home, '.graphcoolrc'), 'utf-8')).toMatchSnapshot();
        fs.removeSync(home);
    });
    test('.graphcool with yaml, existing backup file', function () {
        var home = getTmpDir_1.getTmpDir();
        fs.outputFileSync(path.join(home, '.graphcool'), "clusters:\n  local:\n    host: 'http://localhost:60000'\n  remote:\n    host: 'https://remote.graph.cool'\n    clusterSecret: 'here-is-a-token'");
        fs.outputFileSync(path.join(home, '.graphcool.backup'), "clusters:\n  local:\n    host: 'http://localhost:60000'\n  remote:\n    host: 'https://remote.graph.cool'\n    clusterSecret: 'here-is-a-token'");
        var out = new interface_1.TestOutput();
        var migrator = new EnvironmentMigrator_1.EnvironmentMigrator(home, out);
        migrator.migrate();
        expect(out.output).toMatchSnapshot();
        expect(fs.readdirSync(home)).toMatchSnapshot();
        fs.removeSync(home);
    });
    test('.graphcool folder, non-existent backup file, non-existent .graphcoolrc', function () {
        var home = getTmpDir_1.getTmpDir();
        fs.outputFileSync(path.join(home, '.graphcool/config.yml'), "clusters:\n  local:\n    host: 'http://localhost:60000'\n  remote:\n    host: 'https://remote.graph.cool'\n    clusterSecret: 'here-is-a-token'");
        var out = new interface_1.TestOutput();
        var migrator = new EnvironmentMigrator_1.EnvironmentMigrator(home, out);
        migrator.migrate();
        expect(out.output).toMatchSnapshot();
        expect(fs.readdirSync(home)).toMatchSnapshot();
        expect(fs.readFileSync(path.join(home, '.graphcoolrc'), 'utf-8')).toMatchSnapshot();
        fs.removeSync(home);
    });
    test('.graphcool folder, non-existent backup file, existing .graphcoolrc', function () {
        var home = getTmpDir_1.getTmpDir();
        fs.outputFileSync(path.join(home, '.graphcool/config.yml'), "clusters:\n  local2:\n    host: 'http://localhost:60000'\n  remote:\n    host: 'https://remote.graph.cool'\n    clusterSecret: 'here-is-a-token'");
        fs.outputFileSync(path.join(home, '.graphcoolrc'), "graphcool-framework:\n  clusters:\n    local:\n      host: 'http://localhost:60000'\n    remote:\n      host: 'https://remote.graph.cool'\n      clusterSecret: 'here-is-a-token'\ngraphcool-1.0:\n  clusters:\n    local:\n      host: 'http://localhost:60002'\n    remote:\n      host: 'https://remote.graph.cool'\n      clusterSecret: 'here-is-a-token'");
        var out = new interface_1.TestOutput();
        var migrator = new EnvironmentMigrator_1.EnvironmentMigrator(home, out);
        migrator.migrate();
        expect(out.output).toMatchSnapshot();
        expect(fs.readdirSync(home)).toMatchSnapshot();
        expect(fs.readFileSync(path.join(home, '.graphcoolrc'), 'utf-8')).toMatchSnapshot();
        fs.removeSync(home);
    });
    test('.graphcool folder, existing backup folder (or file), execute 2 times', function () {
        var home = getTmpDir_1.getTmpDir();
        fs.outputFileSync(path.join(home, '.graphcool/config.yml'), "clusters:\n  local2:\n    host: 'http://localhost:60000'\n  remote:\n    host: 'https://remote.graph.cool'\n    clusterSecret: 'here-is-a-token'");
        fs.outputFileSync(path.join(home, '.graphcool.backup'), "graphcool-framework:\n  clusters:\n    local:\n      host: 'http://localhost:60000'\n    remote:\n      host: 'https://remote.graph.cool'\n      clusterSecret: 'here-is-a-token'\ngraphcool-1.0:\n  clusters:\n    local:\n      host: 'http://localhost:60002'\n    remote:\n      host: 'https://remote.graph.cool'\n      clusterSecret: 'here-is-a-token'");
        var out = new interface_1.TestOutput();
        var migrator = new EnvironmentMigrator_1.EnvironmentMigrator(home, out);
        migrator.migrate();
        // migrate 2 times
        migrator.migrate();
        expect(out.output).toMatchSnapshot();
        expect(fs.readdirSync(home)).toMatchSnapshot();
        fs.removeSync(home);
    });
    test('.graphcoolrc folder, non-existent backup file', function () {
        var home = getTmpDir_1.getTmpDir();
        fs.mkdirpSync(path.join(home, '.graphcoolrc'));
        var out = new interface_1.TestOutput();
        var migrator = new EnvironmentMigrator_1.EnvironmentMigrator(home, out);
        migrator.migrate();
        // migrate 2 times
        migrator.migrate();
        expect(out.output).toMatchSnapshot();
        expect(fs.readdirSync(home)).toMatchSnapshot();
        fs.removeSync(home);
    });
    test('.graphcoolrc folder, existing backup folder (or file)', function () {
        var home = getTmpDir_1.getTmpDir();
        fs.mkdirpSync(path.join(home, '.graphcoolrc'));
        fs.mkdirpSync(path.join(home, '.graphcoolrc.backup'));
        var out = new interface_1.TestOutput();
        var migrator = new EnvironmentMigrator_1.EnvironmentMigrator(home, out);
        migrator.migrate();
        expect(out.output).toMatchSnapshot();
        expect(fs.readdirSync(home)).toMatchSnapshot();
        fs.removeSync(home);
    });
    test('.graphcoolrc file with valid yaml, non-existent backup file', function () {
        var home = getTmpDir_1.getTmpDir();
        fs.outputFileSync(path.join(home, '.graphcoolrc'), "clusters:\n  local:\n    host: 'http://localhost:60000'\n  remote:\n    host: 'https://remote.graph.cool'\n    clusterSecret: 'here-is-a-token'");
        var out = new interface_1.TestOutput();
        var migrator = new EnvironmentMigrator_1.EnvironmentMigrator(home, out);
        migrator.migrate();
        expect(out.output).toMatchSnapshot();
        expect(fs.readdirSync(home)).toMatchSnapshot();
        expect(fs.readFileSync(path.join(home, '.graphcoolrc'), 'utf-8')).toMatchSnapshot();
        fs.removeSync(home);
    });
    test('.graphcoolrc file with valid yaml, existing backup folder (or file)', function () {
        var home = getTmpDir_1.getTmpDir();
        fs.outputFileSync(path.join(home, '.graphcoolrc'), "clusters:\n  local:\n    host: 'http://localhost:60000'\n  remote:\n    host: 'https://remote.graph.cool'\n    clusterSecret: 'here-is-a-token'");
        fs.outputFileSync(path.join(home, '.graphcoolrc.backup'), "clusters:\n  local:\n    host: 'http://localhost:60000'\n  remote:\n    host: 'https://remote.graph.cool'\n    clusterSecret: 'here-is-a-token'");
        var out = new interface_1.TestOutput();
        var migrator = new EnvironmentMigrator_1.EnvironmentMigrator(home, out);
        migrator.migrate();
        expect(out.output).toMatchSnapshot();
        expect(fs.readdirSync(home)).toMatchSnapshot();
        expect(fs.readFileSync(path.join(home, '.graphcoolrc'), 'utf-8')).toMatchSnapshot();
        fs.removeSync(home);
    });
    test('.graphcoolrc file with invalid yaml, non-existent backup file', function () {
        var home = getTmpDir_1.getTmpDir();
        fs.outputFileSync(path.join(home, '.graphcoolrc'), "clusters\n  local:\n    host: http://localhost:60000'\n  remote:\n    host: 'https://remote.graph.cool'\n    clusterSecret: 'here-is-a-token'");
        var out = new interface_1.TestOutput();
        var migrator = new EnvironmentMigrator_1.EnvironmentMigrator(home, out);
        migrator.migrate();
        expect(out.output).toMatchSnapshot();
        expect(fs.readdirSync(home)).toMatchSnapshot();
        expect(fs.readFileSync(path.join(home, '.graphcoolrc'), 'utf-8')).toMatchSnapshot();
        fs.removeSync(home);
    });
    test('.graphcoolrc file with invalid yaml, existing backup folder (or file)', function () {
        var home = getTmpDir_1.getTmpDir();
        fs.outputFileSync(path.join(home, '.graphcoolrc'), "clusters:\n  local:\n    host 'http://localhost:60000'\n  remote:\n    host: https://remote.graph.cool'\n    clusterSecret: 'here-is-a-token'");
        fs.outputFileSync(path.join(home, '.graphcoolrc.backup'), "clusters:\n  local:\n    host: 'http://localhost:60000'\n  remote:\n    host: 'https://remote.graph.cool'\n    clusterSecret: 'here-is-a-token'");
        var out = new interface_1.TestOutput();
        var migrator = new EnvironmentMigrator_1.EnvironmentMigrator(home, out);
        migrator.migrate();
        expect(out.output).toMatchSnapshot();
        expect(fs.readdirSync(home)).toMatchSnapshot();
        expect(fs.readFileSync(path.join(home, '.graphcoolrc'), 'utf-8')).toMatchSnapshot();
        fs.removeSync(home);
    });
});
//# sourceMappingURL=EnvironmentMigrator.test.js.map